pub struct Texture {
pub texture_id: i32,
pub image_name: String,
/* private fields */
}Expand description
OpenGL texture. Upon creation, it defines a sampler uniform and initializes a texture buffer, loading it with wit the file’s data. Current supported format(s): png
Fields
texture_id: i32image_name: StringImplementations
Sourceimpl Texture
impl Texture
Sourcepub fn new(image_name: &str, options: TextureOptions) -> Texture
pub fn new(image_name: &str, options: TextureOptions) -> Texture
Creates a new texture ready to be loaded It will generate a texture buffer on the gl state machine
Sourcepub fn set_uniform(&self, program: &ShaderProgram)
pub fn set_uniform(&self, program: &ShaderProgram)
Sets the sampler fragment shader Uniform